@@ -10,7 +10,9 @@ release_info <- function(repo = guess_repo(), .token = get_token()) {
 
   # get release ids
   releases <- maybe(gh::gh("/repos/:owner/:repo/releases",
-                           owner = r[[1]], repo = r[[2]], .token = .token
+                           owner = r[[1]], repo = r[[2]],
+                           .limit = Inf,
+                           .token = .token
   ),
   otherwise = stop(api_error_msg(r))
   )
@@ -18,17 +20,23 @@ release_info <- function(repo = guess_repo(), .token = get_token()) {
   # fetch asset meta-data individually, see #19
   for (i in seq_along(releases)) {
      a <- gh::gh(endpoint = "/repos/:owner/:repo/releases/:release_id/assets",
-                 owner = r[[1]], repo = r[[2]], release_id = releases[[i]]$id,
+                 owner = r[[1]],
+                 repo = r[[2]],
+                 release_id = releases[[i]]$id,
+                 .limit = Inf,
                  .token = .token)
+
      if (!identical(a[[1]], "")) {
       # if the i'th release does not have any assets then we skip updating
       # the assets in the releases object
+
+      ## Now use assets given by the release id as the returned assets
       class(a) <- "list"
       attributes(a) <- NULL
       releases[[i]]$assets <- a
     }
   }
-  
+
   # return result
   releases
 }
@@ -51,6 +59,7 @@ release_data <- function(x, r) {
       upload_url = x$upload_url,
       browser_download_url = "",
       id = "",
+      state = "",
       stringsAsFactors = FALSE
     ))
 
@@ -70,14 +79,20 @@ release_data <- function(x, r) {
     repo = r[[2]],
     upload_url = x$upload_url,
     browser_download_url = vapply(
-      x$assets, `[[`, character(1),
+      x$assets, `[[`, character(1L),
       "browser_download_url"
     ),
-    id = vapply(x$assets, `[[`, integer(1), "id"),
+    id = vapply(x$assets, `[[`, integer(1L), "id"),
+    state = vapply(x$assets, `[[`, character(1L), "state"),
     stringsAsFactors = FALSE
   )
 }
 
+null_chr <- function(x){
+  if(is.null(x)) return("")
+  as.character(NA)
+}
+
 pb_info_fn <- function(repo = guess_repo(),
                        tag = NULL,
                        .token = get_token()) {
@@ -142,3 +157,5 @@ pb_info <- function(repo = guess_repo(),
   }
 
 }
+
+
